==> gemforged-3.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/util/GemforgedLootTableModifiers.java <==
package net.trique.gemforged.util;

import net.fabricmc.fabric.api.loot.v2.LootTableEvents;
import net.minecraft.class_219;
import net.minecraft.class_2960;
import net.minecraft.class_44;
import net.minecraft.class_55;
import net.minecraft.class_77;
import net.trique.gemforged.item.GemforgedItems;

public final class GemforgedLootTableModifiers {
    private GemforgedLootTableModifiers() {}

    private static final class_2960 ANCIENT_CITY_CHEST = new class_2960("minecraft", "chests/ancient_city");
    private static final class_2960 BASTION_BRIDGE = new class_2960("minecraft", "chests/bastion_bridge");
    private static final class_2960 BASTION_HOGLIN = new class_2960("minecraft", "chests/bastion_hoglin_stable");
    private static final class_2960 BASTION_OTHER = new class_2960("minecraft", "chests/bastion_other");
    private static final class_2960 BASTION_TREASURE = new class_2960("minecraft", "chests/bastion_treasure");
    private static final class_2960 DESERT_PYRAMID = new class_2960("minecraft", "chests/desert_pyramid");
    private static final class_2960 JUNGLE_TEMPLE = new class_2960("minecraft", "chests/jungle_temple");
    private static final class_2960 END_CITY_TREASURE = new class_2960("minecraft", "chests/end_city_treasure");
    private static final class_2960 OCEAN_RUIN_COLD_ARCH = new class_2960("minecraft", "archaeology/ocean_ruin_cold");
    private static final class_2960 PILLAGER_OUTPOST = new class_2960("minecraft", "chests/pillager_outpost");

    public static void register() {
        LootTableEvents.MODIFY.register((resourceManager, lootManager, id, tableBuilder, source) -> {
            if (id.equals(ANCIENT_CITY_CHEST)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.DAGGER_TEMPLATE), 0.25f));
            } else if (id.equals(BASTION_BRIDGE) || id.equals(BASTION_HOGLIN) || id.equals(BASTION_OTHER)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.CHARM_TEMPLATE), 0.25f));
            } else if (id.equals(BASTION_TREASURE)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.CHARM_TEMPLATE), 0.50f));
            } else if (id.equals(DESERT_PYRAMID)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.STAFF_TEMPLATE), 0.10f));
            } else if (id.equals(JUNGLE_TEMPLE)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.BLADE_TEMPLATE), 0.25f));
            } else if (id.equals(OCEAN_RUIN_COLD_ARCH)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.PRISM_TEMPLATE), 0.25f));
            } else if (id.equals(END_CITY_TREASURE)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.HORN_TEMPLATE), 0.25f));
            } else if (id.equals(PILLAGER_OUTPOST)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.TOTEM_TEMPLATE), 0.25f));
            }
        });
    }

    private static class_55 makePoolWithChance(class_77.Builder<?> entry, float chance) {
        return class_55.method_347()
                .method_352(class_44.method_32448(1))
                .method_356(class_219.method_932(chance))
                .method_351(entry)
                .method_355();
    }
}

==> gemforged-4.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/util/GemforgedLootTableModifiers.java <==
package net.trique.gemforged.util;

import net.fabricmc.fabric.api.loot.v2.LootTableEvents;
import net.minecraft.class_219;
import net.minecraft.class_2960;
import net.minecraft.class_44;
import net.minecraft.class_55;
import net.minecraft.class_77;
import net.trique.gemforged.item.GemforgedItems;

public final class GemforgedLootTableModifiers {
    private GemforgedLootTableModifiers() {}

    private static final class_2960 ANCIENT_CITY_CHEST = new class_2960("minecraft", "chests/ancient_city");
    private static final class_2960 BASTION_BRIDGE = new class_2960("minecraft", "chests/bastion_bridge");
    private static final class_2960 BASTION_HOGLIN = new class_2960("minecraft", "chests/bastion_hoglin_stable");
    private static final class_2960 BASTION_OTHER = new class_2960("minecraft", "chests/bastion_other");
    private static final class_2960 BASTION_TREASURE = new class_2960("minecraft", "chests/bastion_treasure");
    private static final class_2960 DESERT_PYRAMID = new class_2960("minecraft", "chests/desert_pyramid");
    private static final class_2960 JUNGLE_TEMPLE = new class_2960("minecraft", "chests/jungle_temple");
    private static final class_2960 END_CITY_TREASURE = new class_2960("minecraft", "chests/end_city_treasure");
    private static final class_2960 OCEAN_RUIN_COLD_ARCH = new class_2960("minecraft", "archaeology/ocean_ruin_cold");
    private static final class_2960 PILLAGER_OUTPOST = new class_2960("minecraft", "chests/pillager_outpost");
    private static final class_2960 WOODLAND_MANSION = new class_2960("minecraft", "chests/woodland_mansion");

    public static void register() {
        LootTableEvents.MODIFY.register((resourceManager, lootManager, id, tableBuilder, source) -> {
            if (id.equals(ANCIENT_CITY_CHEST)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.DAGGER_TEMPLATE), 0.25f));
            } else if (id.equals(BASTION_BRIDGE) || id.equals(BASTION_HOGLIN) || id.equals(BASTION_OTHER)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.CHARM_TEMPLATE), 0.25f));
            } else if (id.equals(BASTION_TREASURE)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.CHARM_TEMPLATE), 0.50f));
            } else if (id.equals(DESERT_PYRAMID)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.STAFF_TEMPLATE), 0.10f));
            } else if (id.equals(JUNGLE_TEMPLE)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.BLADE_TEMPLATE), 0.25f));
            } else if (id.equals(OCEAN_RUIN_COLD_ARCH)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.PRISM_TEMPLATE), 0.25f));
            } else if (id.equals(END_CITY_TREASURE)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.HORN_TEMPLATE), 0.25f));
            } else if (id.equals(PILLAGER_OUTPOST)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.TOTEM_TEMPLATE), 0.25f));
            } else if (id.equals(WOODLAND_MANSION)) {
                tableBuilder.pool(makePoolWithChance(class_77.method_411(GemforgedItems.BOW_TEMPLATE), 0.50f));
            }
        });
    }

    private static class_55 makePoolWithChance(class_77.Builder<?> entry, float chance) {
        return class_55.method_347()
                .method_352(class_44.method_32448(1))
                .method_356(class_219.method_932(chance))
                .method_351(entry)
                .method_355();
    }
}
